@@ -21,7 +21,7 @@ from gateways.common.cs18_api_requests import (
     UpdateSpaceRequest,
     ProductionEnvironment, DebuggingServiceValue, SpaceCloudAccountInfraSettingsRequest,
     AddK8SComputeServiceToSpaceRequest, UpdateK8SComputeServiceInSpaceRequest, AwsCloudProviderSettingsModel,
-    NewUserSurveyRequest, AddSpaceTerraformModuleRequest, UpdateSpaceTerraformModuleRequest, AddSpaceHelmChartRequest)
+    NewUserSurveyRequest, AddSpaceTerraformModuleRequest, UpdateSpaceTerraformModuleRequest)
 from gateways.common.cs18_api_responses import (AccountStatusResponse, BlueprintFileResponse, BlueprintResponse,
                                                 CatalogForGetAllResponse, CatalogForGetResponse, CloudAccountResponse,
                                                 CreateProductionResponse, CreateSandboxResponse, GetSpaceResponse,
@@ -893,11 +893,6 @@ class Colony:
         GatewayUtils.handle_response(response=resp, return_codes=[200])
         return resp.content
 
-    def get_api_response(self, method_url: str) -> bytes:
-        resp = self.session.get(url=method_url)
-        GatewayUtils.handle_response(response=resp, return_codes=[200])
-        return resp.content
-
     def validate_blueprint(self, blueprint: str, deployment_type: str = 'sandbox', branch: str = None,
                            commit: str = None) -> BlueprintValidationResponse:
         method_url = self._api_root.blueprint_validation.blueprint_validation_by_space_name(space_name=self.space)
@@ -1719,29 +1714,6 @@ class Colony:
         res = self.session.delete(url=method_url)
         GatewayUtils.handle_response(response=res, return_codes=[200])
 
-    def get_space_helm_charts(self):
-        method_url = self._api_root.spaces.space_helm_charts(space_name=self.space)
-        response = self.session.get(url=method_url)
-        GatewayUtils.handle_response(response=response, return_codes=[200])
-        json_result = json.loads(response.text)
-        return [Converters.create_space_helm_chart_response(item)
-                for item in json_result]
-
-    def create_space_helm_chart(self, request: AddSpaceHelmChartRequest):
-        method_url = self._api_root.spaces.space_helm_charts(space_name=self.space)
-        response = self.session.post(url=method_url, json=Utils.get_as_json(request))
-        GatewayUtils.handle_response(response=response, return_codes=[200])
-
-    def update_space_helm_chart(self, chart_name: str, request: AddSpaceHelmChartRequest):
-        method_url = self._api_root.spaces.space_helm_chart(space_name=self.space, helm_chart=chart_name)
-        response = self.session.put(url=method_url, json=Utils.get_as_json(request))
-        GatewayUtils.handle_response(response=response, return_codes=[200])
-
-    def delete_space_helm_chart(self, chart_name: str):
-        method_url = self._api_root.spaces.space_helm_chart(space_name=self.space, helm_chart=chart_name)
-        response = self.session.delete(url=method_url)
-        GatewayUtils.handle_response(response=response, return_codes=[200])
-
 
 class SandboxesHandler:
     def __init__(self):
